diff --git a/MtApi5/MtApi5Client.cs b/MtApi5/MtApi5Client.cs
index eb27bde5..667ad424 100755
--- a/MtApi5/MtApi5Client.cs
+++ b/MtApi5/MtApi5Client.cs
@@ -2710,14 +2710,14 @@ namespace MtApi5
}
///
///The function returns the handle of the Force Index indicator.
///
///The symbol name of the security, the data of which should be used to calculate the indicator.
///The value of the period can be one of the ENUM_TIMEFRAMES enumeration values, 0 means the current timeframe.
- public int iForce(string symbol, ENUM_TIMEFRAMES period)
+ public int iFractals(string symbol, ENUM_TIMEFRAMES period)
{
Dictionary cmdParams = new() { { "Symbol", symbol ?? string.Empty }, { "Period", (int)period } };
- return SendCommand(ExecutorHandle, Mt5CommandType.iForce, cmdParams);
+ return SendCommand(ExecutorHandle, Mt5CommandType.iFractals, cmdParams);
}
///
@@ -2710,14 +2710,14 @@ namespace MtApi5
}
///
- ///The function returns the handle of the Force Index indicator.
+ ///The function returns the handle of the Fractals indicator.
///
///The symbol name of the security, the data of which should be used to calculate the indicator.